.. :changelog:

History
-------

0.8.4 [2017-09-18]
* Add loglevel arg

0.8.3 [2017-09-18]
* Add processes arg to stefuna
* Add timestamp to log format

0.8.2 [2017-08-16]
* Set the region based on region in activity ARN.

0.8.1 [2017-08-15]
* First public release
